from __future__ import print_function
import json
import random
import argparse

def read_json_or_get_empty_dict(file, mode="r"):
    try:
        with open(file, mode) as f:
            content = json.load(f)
        return content
    except IOError:
        return dict(mac_addresses=dict())

def write_json(content, file, mode="w+"):
    with open(file, mode) as f:
        f.write(json.dumps(content))


def randomMAC():
    mac = [ 0x00, 0x16, 0x3e,
        random.randint(0x00, 0x7f),
        random.randint(0x00, 0xff),
        random.randint(0x00, 0xff) ]
    return ':'.join(map(lambda x: "%02x" % x, mac))

def uniqueMAC(existing_mac_addresses):
    mac = randomMAC()
    while mac in existing_mac_addresses:
        mac = randomMAC()
    return mac


def get_address_from_file(hostname, file):

    virt_hardware_config = read_json_or_get_empty_dict(file)

    # Try to get the mac address for the given hostname
    try:
        new_mac_address = virt_hardware_config["mac_addresses"][hostname]

    # Generate a new mac address when it does not exists yet
    except KeyError:
        existing_addresses = set(virt_hardware_config["mac_addresses"].values())

        new_mac_address = virt_hardware_config["mac_addresses"][hostname] = uniqueMAC(existing_mac_addresses=existing_addresses)

        write_json(virt_hardware_config, file)

        status = "CHANGED"
    else:
        status = "OK"

    msg = dict()

    msg[hostname] = new_mac_address

    stdout_lines = [json.dumps(msg), status]

    return("\n".join(stdout_lines))


if __name__ == "__main__":

    parser = argparse.ArgumentParser()

    parser.add_argument("--hostname",
                        required=True,
                        help="Hostname of the virtual machine")
    parser.add_argument("--file",
                        required=True,
                        help="Path to file with all mac addresses")

    args = parser.parse_args()

    msg = get_address_from_file(args.hostname, args.file)

    print(msg)
