#!/bin/bash

set -e
# Update virtual network dhcp section in live and in its definition
# On success, output a JSON object with a 'changed' item.

if [[ $# -ne 4 ]] && [[ $# -ne 5 ]]; then
    echo "Wrong number of arguments. Usage: $0 <network> <hostname> <mac_address> <ipv4> <qemu_uri>"
    exit 1
fi

NETWORK=$1
HOSTNAME=$2
MAC_ADDRESS=$3
IPV4=$4
QEMU_URI=$5

if [ -z "$QEMU_URI" ]; then
  QEMU_URI=qemu:///system
fi

status=$(virsh --connect "$QEMU_URI" net-dumpxml $NETWORK | grep $HOSTNAME  && echo "OK" || echo "CHANGED")

if [ "$status" == "CHANGED" ]; then
  virsh --connect "$QEMU_URI" net-update $NETWORK add ip-dhcp-host "<host mac='$MAC_ADDRESS' name='$HOSTNAME' ip='$IPV4' />" --live --config > /dev/null
  echo "CHANGED"
  exit 0
fi

echo "OK"
exit 0
